==> lxqt-panel_0.15.0.orig.tar.xz: lxqt-panel-0.15.0/plugin-taskbar/translations/taskbar_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../lxqttaskbar.cpp" line="650"/>
        <source>Activate task %1</source>
        <translation>Aktyvuoti užduotį %1</translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="576"/>
        <source>Application</source>
        <translation>Programa</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="610"/>
        <source>To &amp;Desktop</source>
        <translation>Į &amp;darbalaukį</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="612"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Visus darbalaukius</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="620"/>
        <source>Desktop &amp;%1</source>
        <translation>Darbalaukį &amp;%1</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="627"/>
        <source>&amp;To Current Desktop</source>
        <translation>Į &amp;esamą darbalaukį</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="635"/>
        <source>&amp;Move</source>
        <translation>&amp;Perkelti</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="638"/>
        <source>Resi&amp;ze</source>
        <translation>Keisti dy&amp;dį</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="645"/>
        <source>Ma&amp;ximize</source>
        <translation>Iš&amp;skleisti</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="652"/>
        <source>Maximize vertically</source>
        <translation>Išskleisti vertikaliai</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="657"/>
        <source>Maximize horizontally</source>
        <translation>Išskleisti horizontaliai</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="663"/>
        <source>&amp;Restore</source>
        <translation>&amp;Atkurti</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="667"/>
        <source>Mi&amp;nimize</source>
        <translation>Sus&amp;kleisti</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="673"/>
        <source>Roll down</source>
        <translation>Nuraityti</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="679"/>
        <source>Roll up</source>
        <translation>Užraityti</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="687"/>
        <source>&amp;Layer</source>
        <translation>S&amp;luoksnis</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="689"/>
        <source>Always on &amp;top</source>
        <translation>Visada vi&amp;ršuje</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="695"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normalus</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="701"/>
        <source>Always on &amp;bottom</source>
        <translation>Visada a&amp;pačioje</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="709"/>
        <source>&amp;Close</source>
        <translation>&amp;Užverti</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="82"/>
        <source>Group</source>
        <translation>Grupė</translation>
    </message>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="84"/>
        <source>Close group</source>
        <translation>Užverti grupę</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>Užduočių tvarkytuvės nustatymai</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Bendra</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation>Rodyti tik langus iš darbalaukio</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation>Rodyti tik langus iš &amp;skydelio ekrano</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation>Rodyti tik suskleistus langus</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>Suskleistus langus iškelti esamame darbalaukyje</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>Užverti, spustelėjus viduriniu pelės mygtuku</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="49"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation>Perjunginėti langus, slenkant pelės ratuku</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="143"/>
        <source>Window &amp;grouping</source>
        <translation>Langų &amp;grupavimas</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="152"/>
        <source>Show popup on mouse hover</source>
        <translation>Užvedus pelę, rodyti iškylantįjį langą</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="162"/>
        <source>Appearance</source>
        <translation>Išvaizda</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="171"/>
        <source>Button style</source>
        <translation>Mygtukų stilius</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="181"/>
        <source>Maximum button width</source>
        <translation>Didžiausias mygtuko plotis</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="125"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="194"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="220"/>
        <source> px</source>
        <translation> pikselių</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="86"/>
        <source>Mouse Wheel</source>
        <translation>Pelės ratukas</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Wheel Delta Threshold</source>
        <translation>Ratuko delta slenkstis</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="207"/>
        <source>Maximum button height</source>
        <translation>Didžiausias mygtuko aukštis</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="233"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation>Automatiškai &amp;pasukti mygtukus, jei skydelis vertikalus</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="240"/>
        <source>Use icons by WindowClass, if available</source>
        <translation>Jei prieinama, naudoti WindowClass piktogramas</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="44"/>
        <source>Icon and text</source>
        <translation>Piktograma ir tekstas</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="45"/>
        <source>Only icon</source>
        <translation>Tik piktograma</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Only text</source>
        <translation>Tik tekstas</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="48"/>
        <source>Disabled</source>
        <translation>Išjungta</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="50"/>
        <source>Scroll up to raise, down to minimize</source>
        <translation>Slinkti aukštyn norint iškelti, žemyn - norint suskleisti</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="51"/>
        <source>Scroll up to minimize, down to raise</source>
        <translation>Slinkti aukštyn norint suskleisti, žemyn - norint iškelti</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="53"/>
        <source>Current</source>
        <translation>Esamo</translation>
    </message>
</context>
</TS>

==> lxqt-panel-0.15.1.tar.xz: lxqt-panel-0.15.1/plugin-taskbar/translations/taskbar_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../lxqttaskbar.cpp" line="655"/>
        <source>Activate task %1</source>
        <translation>Aktyvuoti užduotį %1</translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="635"/>
        <source>Application</source>
        <translation>Programa</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="669"/>
        <source>To &amp;Desktop</source>
        <translation>Į &amp;darbalaukį</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="671"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Visus darbalaukius</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="679"/>
        <source>Desktop &amp;%1</source>
        <translation>Darbalaukį &amp;%1</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="686"/>
        <source>&amp;To Current Desktop</source>
        <translation>Į &amp;esamą darbalaukį</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="694"/>
        <source>&amp;Move</source>
        <translation>&amp;Perkelti</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="697"/>
        <source>Resi&amp;ze</source>
        <translation>Keisti dy&amp;dį</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="704"/>
        <source>Ma&amp;ximize</source>
        <translation>Iš&amp;skleisti</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="711"/>
        <source>Maximize vertically</source>
        <translation>Išskleisti vertikaliai</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="716"/>
        <source>Maximize horizontally</source>
        <translation>Išskleisti horizontaliai</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="722"/>
        <source>&amp;Restore</source>
        <translation>&amp;Atkurti</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="726"/>
        <source>Mi&amp;nimize</source>
        <translation>Sus&amp;kleisti</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="732"/>
        <source>Roll down</source>
        <translation>Nuraityti</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="738"/>
        <source>Roll up</source>
        <translation>Užraityti</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="746"/>
        <source>&amp;Layer</source>
        <translation>S&amp;luoksnis</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="748"/>
        <source>Always on &amp;top</source>
        <translation>Visada vi&amp;ršuje</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="754"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normalus</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="760"/>
        <source>Always on &amp;bottom</source>
        <translation>Visada a&amp;pačioje</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="768"/>
        <source>&amp;Close</source>
        <translation>&amp;Užverti</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="82"/>
        <source>Group</source>
        <translation>Grupė</translation>
    </message>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="84"/>
        <source>Close group</source>
        <translation>Užverti grupę</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>Užduočių tvarkytuvės nustatymai</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Bendra</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation>Rodyti tik langus iš darbalaukio</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation>Rodyti tik langus iš &amp;skydelio ekrano</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation>Rodyti tik suskleistus langus</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>Suskleistus langus iškelti esamame darbalaukyje</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>Užverti, spustelėjus viduriniu pelės mygtuku</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="49"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation>Perjunginėti langus, slenkant pelės ratuku</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="143"/>
        <source>Window &amp;grouping</source>
        <translation>Langų &amp;grupavimas</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="152"/>
        <source>Show popup on mouse hover</source>
        <translation>Užvedus pelę, rodyti iškylantįjį langą</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="162"/>
        <source>Appearance</source>
        <translation>Išvaizda</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="171"/>
        <source>Button style</source>
        <translation>Mygtukų stilius</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="181"/>
        <source>Maximum button width</source>
        <translation>Didžiausias mygtuko plotis</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="125"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="194"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="220"/>
        <source> px</source>
        <translation> pikselių</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="86"/>
        <source>Mouse Wheel</source>
        <translation>Pelės ratukas</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Wheel Delta Threshold</source>
        <translation>Ratuko delta slenkstis</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="207"/>
        <source>Maximum button height</source>
        <translation>Didžiausias mygtuko aukštis</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="233"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation>Automatiškai &amp;pasukti mygtukus, jei skydelis vertikalus</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="240"/>
        <source>Use icons by WindowClass, if available</source>
        <translation>Jei prieinama, naudoti WindowClass piktogramas</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="44"/>
        <source>Icon and text</source>
        <translation>Piktograma ir tekstas</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="45"/>
        <source>Only icon</source>
        <translation>Tik piktograma</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Only text</source>
        <translation>Tik tekstas</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="48"/>
        <source>Disabled</source>
        <translation>Išjungta</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="50"/>
        <source>Scroll up to raise, down to minimize</source>
        <translation>Slinkti aukštyn norint iškelti, žemyn - norint suskleisti</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="51"/>
        <source>Scroll up to minimize, down to raise</source>
        <translation>Slinkti aukštyn norint suskleisti, žemyn - norint iškelti</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="52"/>
        <source>Scroll up to move to next desktop, down to previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="53"/>
        <source>Scroll up to move to previous desktop, down to next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="55"/>
        <source>Current</source>
        <translation>Esamo</translation>
    </message>
</context>
</TS>
